@@ -38,7 +38,9 @@
 
 typedef unsigned char uint8_t;
 typedef unsigned short uint16_t;
+typedef short int16_t;
 typedef unsigned uint32_t;
+typedef int int32_t;
 typedef unsigned __int64 uint64_t;
 
 #else /* !defined _MSC_VER */
@@ -89,7 +91,9 @@ namespace libvisio
 
 uint8_t readU8(WPXInputStream *input);
 uint16_t readU16(WPXInputStream *input);
+int16_t readS16(WPXInputStream *input);
 uint32_t readU32(WPXInputStream *input);
+int32_t readS32(WPXInputStream *input);
 uint64_t readU64(WPXInputStream *input);
 
 double readDouble(WPXInputStream *input);
